@@ -23,20 +23,19 @@ import sys
 import operator
 import textwrap
 
+import IPython
 from IPython.core.error import UsageError
 from IPython.utils.ipstruct import Struct
 from IPython.core.page import page
 from IPython.core.interactiveshell import InteractiveShell
 from IPython.terminal.ipapp import launch_new_instance
-
-try:     # IPython 4.x
-    from traitlets.config.application import Application
-except:  # IPython < 4.x
-    from IPython.config.application import Application
+from packaging.version import Version
+from traitlets.config.application import Application
 
 import tango
 import tango.utils
 
+from . import __version__
 from . import common
 from .eventlogger import EventLogger
 from .install import install, is_installed, install_kernel
@@ -58,6 +57,21 @@ _PYTHON_ERR = "__python_error"
 _tango_init = False
 
 
+def _get_ipython_major_version():
+    ver = None
+    if hasattr(IPython, "Release"):
+        ver = IPython.Release.version.split(".")
+    elif hasattr(IPython, "release"):
+        ver = IPython.release.version.split(".")
+    return int(ver[0]) if ver else 0
+
+
+if _get_ipython_major_version() >= 5:
+    _DEFAULTCOLOR = 'Neutral'
+else:
+    _DEFAULTCOLOR = 'Linux'
+
+
 # IPython utilities
 
 def get_pylab_mode():
@@ -702,12 +716,12 @@ def __build_color_scheme(ip, name):
     SyntaxColors = ip.IP.SyntaxTB.color_scheme_table
     InspectColors = IPython.OInspect.InspectColors
 
-    promptTangoColors = PromptColors['Linux'].copy(name)
-    ANSITangoColors = ANSICodeColors['Linux'].copy(name)
-    exceptionTangoColors = ExceptionColors['Linux'].copy(name)
-    TBTangoColors = TBColors['Linux'].copy(name)
-    syntaxTangoColors = SyntaxColors['Linux'].copy(name)
-    inspectTangoColors = InspectColors['Linux'].copy(name)
+    promptTangoColors = PromptColors[_DEFAULTCOLOR].copy(name)
+    ANSITangoColors = ANSICodeColors[_DEFAULTCOLOR].copy(name)
+    exceptionTangoColors = ExceptionColors[_DEFAULTCOLOR].copy(name)
+    TBTangoColors = TBColors[_DEFAULTCOLOR].copy(name)
+    syntaxTangoColors = SyntaxColors[_DEFAULTCOLOR].copy(name)
+    inspectTangoColors = InspectColors[_DEFAULTCOLOR].copy(name)
 
     # initialize prompt with default tango colors
     promptTangoColors.colors.in_prompt  = InputTermColors.Purple
@@ -725,7 +739,7 @@ def __build_color_scheme(ip, name):
 
     if ip.IP.isthreaded:
         TBThreadedColors = ip.IP.sys_excepthook.color_scheme_table
-        TBThreadedTangoColors = TBThreadedColors['Linux'].copy(name)
+        TBThreadedTangoColors = TBThreadedColors[_DEFAULTCOLOR].copy(name)
         ret["TBThreaded"] = TBThreadedColors, TBThreadedTangoColors
     return ret
 
@@ -744,10 +758,10 @@ def init_pytango(ip):
     # add completers
     dp_completer = __completer_wrapper(__DeviceProxy_completer)
     attr_completer = __completer_wrapper(__AttributeProxy_completer)
-    ip.set_hook('complete_command', dp_completer, re_key = ".*DeviceProxy[^\w\.]+")
-    ip.set_hook('complete_command', dp_completer, re_key = ".*Device[^\w\.]+")
-    ip.set_hook('complete_command', attr_completer, re_key = ".*AttributeProxy[^\w\.]+")
-    ip.set_hook('complete_command', attr_completer, re_key = ".*Attribute[^\w\.]+")
+    ip.set_hook('complete_command', dp_completer, re_key = r".*DeviceProxy[^\w\.]+")
+    ip.set_hook('complete_command', dp_completer, re_key = r".*Device[^\w\.]+")
+    ip.set_hook('complete_command', attr_completer, re_key = r".*AttributeProxy[^\w\.]+")
+    ip.set_hook('complete_command', attr_completer, re_key = r".*Attribute[^\w\.]+")
 
     ip.set_custom_exc((Exception,), __exc_handler)
 
@@ -819,7 +833,7 @@ def init_db(parameter_s=''):
         exists = klass in user_ns
         if not exists or klass in old_junk:
             c = DeviceClassCompleter(klass, devices)
-            ip.set_hook('complete_command', c, re_key = ".*" + klass + "[^\w\.]+")
+            ip.set_hook('complete_command', c, re_key = r".*" + klass + r"[^\w\.]+")
             exposed_klasses[klass] = tango.DeviceProxy
 
     # expose classes no user namespace
@@ -1238,7 +1252,7 @@ def load_config(config):
     import IPython.utils.coloransi
 
     d = {
-        "version": str(common.get_pytango_version()),
+        "version": __version__,
         "pyver": str(common.get_python_version()),
         "ipyver": str(common.get_ipython_version()),
         "pytangover": str(common.get_pytango_version())
@@ -1260,13 +1274,13 @@ def load_config(config):
     # InteractiveShell
     # ------------------------------------
     i_shell = config.InteractiveShell
-    i_shell.colors = 'Linux'
+    i_shell.colors = _DEFAULTCOLOR
 
     # ------------------------------------
     # PromptManager (ipython >= 0.12)
     # ------------------------------------
 
-    if common.get_ipython_version() < '5.0':
+    if common.get_ipython_version() < Version('5.0'):
         prompt = config.PromptManager
         prompt.in_template = 'ITango [\\#]: '
         prompt.out_template = 'Result [\\#]: '
@@ -1347,18 +1361,11 @@ def patch_qt_console():
     Return the customized application class.
     """
     # Traitlets imports
-    try:  # IPython 4.x
-        from traitlets import Unicode
-    except ImportError:  # IPython < 4.x
-        from IPython.utils.traitlets import Unicode
+    from traitlets import Unicode
 
-    # Qt concole imports
-    try:
-        from qtconsole import rich_ipython_widget
-        from qtconsole import qtconsoleapp
-    except ImportError:
-        from IPython.qt.console import rich_ipython_widget
-        from IPython.qt.console import qtconsoleapp
+    # Qt console imports
+    from qtconsole import rich_ipython_widget
+    from qtconsole import qtconsoleapp
 
     # Patch widget factory
     try:
